Index: chrome/install_static/install_constants.h |
diff --git a/chrome/install_static/install_constants.h b/chrome/install_static/install_constants.h |
index 1b79bceb11e6d970ff653d2340d56df3f74c17bf..a9b07a4e893bb1909b4881a0ea8624b33f26d724 100644 |
--- a/chrome/install_static/install_constants.h |
+++ b/chrome/install_static/install_constants.h |
@@ -58,8 +58,8 @@ struct InstallConstants { |
// True if this mode supports system-level installs. |
bool supports_system_level; |
- // True if this mode supports multi-install. |
- bool supports_multi_install; |
+ // True if this mode supported the now-deprecated multi-install. |
+ bool supported_multi_install; |
}; |
} // namespace install_static |